@@ -24,8 +24,8 @@
 #include <Python.h>
 
 /* Sanity check on the Python version. */
-#if PY_VERSION_HEX < 0x03060000
-#error "This version of PyQt6.sip requires Python v3.6 or later"
+#if PY_VERSION_HEX < 0x03070000
+#error "This version of PyQt6.sip requires Python v3.7 or later"
 #endif
 
 
@@ -45,22 +45,34 @@ extern "C" {
 
 /* The version of the ABI. */
 #define SIP_ABI_MAJOR_VERSION       13
-#define SIP_ABI_MINOR_VERSION       2
-#define SIP_MODULE_PATCH_VERSION    1
+#define SIP_ABI_MINOR_VERSION       4
+#define SIP_MODULE_PATCH_VERSION    0
 
 
 /*
- * The changes to this version of the ABI.
+ * The change history of the ABI.
+ *
+ * v13.4
+ *  - The enum implementation now supports missing members.
+ *  - Published the 'array' type.
+ *  - Added the ctd_sizeof, ctd_array_delete members to sipClassTypeDef.
+ *  - Added the '>' conversion character to sipParseArgs().
+ *
+ * v13.3
+ *  - Python v3.7 or later is required.
  *
  * v13.2
  *  - Added support for SIP_ENUM_UINT_ENUM to represent IntEnums with unsigned
  *    members.
+ *
+ * v13.1
+ *  - Added sipNextExceptionHandler().
  */
 
 
 /* The version of the code generator. */
-#define SIP_VERSION                 0x60501
-#define SIP_VERSION_STR             "6.5.1"
+#define SIP_VERSION                 0x60602
+#define SIP_VERSION_STR             "6.6.2"
 
 /* These are all dependent on the user-specified name of the sip module. */
 #define _SIP_MODULE_FQ_NAME         "PyQt6.sip"
@@ -230,6 +242,7 @@ typedef int (*sipVirtHandlerFunc)(sip_gilstate_t, sipVirtErrorHandlerFunc,
         sipSimpleWrapper *, PyObject *, ...);
 typedef void (*sipAssignFunc)(void *, Py_ssize_t, void *);
 typedef void *(*sipArrayFunc)(Py_ssize_t);
+typedef void (*sipArrayDeleteFunc)(void *);
 typedef void *(*sipCopyFunc)(const void *, Py_ssize_t);
 typedef void (*sipReleaseFunc)(void *, int);
 typedef void (*sipReleaseUSFunc)(void *, int, void *);
@@ -814,6 +827,12 @@ typedef struct _sipClassTypeDef {
 
     /* The mixin initialisation function. */
     initproc ctd_init_mixin;
+
+    /* The optional array delete function. */
+    sipArrayDeleteFunc ctd_array_delete;
+
+    /* The sizeof the class. */
+    size_t ctd_sizeof;
 } sipClassTypeDef;
 
 
@@ -1418,8 +1437,7 @@ const sipAPIDef *sip_init_library(PyObject *mod_dict);
 
 
 /*
- * These are flags that can be passed to sipConvertToArray().  These are held
- * in sw_flags.
+ * These are flags that can be passed to sipConvertToArray().
  */
 #define SIP_READ_ONLY       0x01    /* The array is read-only. */
 #define SIP_OWNS_MEMORY     0x02    /* The array owns its memory. */
